# Python3 Program: tempSerialFromAx.py

# Receives raw temp data (2 bytes) from PICAXE, then converts to C & F.
# Also prints all three data values (ADCval, tempC, and tempF).

# The companion program is tempSerialToPi.bas

# If you haven't already installed pySerial, you ned to type the
# following command in the terminal: sudo apt-get install python3-serial

from time import sleep
import serial
import sys                                  # for KeyboardInterrupt

ser=serial.Serial('/dev/ttyAMA0',9600)      # define and open serial port

print('Waiting for serial data...')
print()                                     # print a blank line

while True:
  try:
    hiByte = ord(ser.read())                #1: (blocking) fetch hiByte, & convert to number
    loByte = ord(ser.read())                    # (blocking) fetch loByte, & convert to number

    ADCval = 256 * hiByte + loByte          #2: compute word value of raw data
    
    tempC = 0.2 * ADCval - 50               #3: compute Centigrade temp
    tempC = round(tempC,1)                  #4: round to one decimal place

    tempF = round(1.8 * tempC + 32,1)       #5: compute Fahrenheit temp    
                                                # (combining above 2 steps into 1) 
                                          
    print ('ADCval =',ADCval,end="; ")      #6: see text
    print ('tempC =',str(tempC)+chr(176),'C; ',end='')
    print ('tempF = ',tempF,chr(176),' F',sep='')
    
  except KeyboardInterrupt:                 # ctrl-c terminates program
    print()                                 # print on new line
    print('Program terminated.')
    ser.close()
    break
